@@ -27,19 +27,7 @@
 #include <stdio.h>
 #include <string.h>
 
-//using namespace application;
 using namespace basis;
-//using namespace configuration;
-//using namespace mathematics;
-//using namespace filesystem;
-//using namespace loggers;
-//using namespace structures;
-//using namespace textual;
-//using namespace timely;
-//using namespace unit_test;
-
-////#undef new
-//is this right way to clean that out..?
 
 namespace application {
 
@@ -56,7 +44,7 @@ const char *emptiness_note = "Empty Stack\n";
 
 basis::mutex &callstack_tracker::__callstack_tracker_synchronizer()
 {
-  static basis::mutex __global_synch_callstacks;
+  thread_local basis::mutex __global_synch_callstacks;
   return __global_synch_callstacks;
 }
 
@@ -65,24 +53,14 @@ basis::mutex &callstack_tracker::__callstack_tracker_synchronizer()
 //! the single instance of callstack_tracker.
 /*!
   this is also an ultra low-level object, although it's not as far down
-as the memory checker.  it can allocate c++ objects and that kind of thing
-just fine.  the object must be stored here rather than in the static basis
-library due to issues in windows dlls.
-  NOTE: the construction process for this is not thread-safe; the static
-program-wide object must be initialized before any threads have started.
-that is normally done in...
-uhhh....
-
-beuller?
-...
-
-
+  as the memory checker.  it can allocate c++ objects and that kind of thing
+  just fine.
 */
-callstack_tracker &program_wide_stack_trace()
+callstack_tracker &thread_wide_stack_trace()
 {
   auto_synchronizer l(callstack_tracker::__callstack_tracker_synchronizer());
 
-  static callstack_tracker *_hidden_trace = NULL_POINTER;
+  thread_local callstack_tracker *_hidden_trace = NULL_POINTER;
   if (!_hidden_trace) {
 #ifdef ENABLE_MEMORY_HOOK
     program_wide_memories().disable();
@@ -124,15 +102,12 @@ callstack_tracker::callstack_tracker()
   _highest(0),
   _unusable(false)
 {
-//printf("callstack ctor\n");
 }
 
 callstack_tracker::~callstack_tracker()
 {
-//printf("!!!!!!!!!!!!!!!!!!   callstack dtor in\n");
   _unusable = true;
   WHACK(_bt);
-//printf("!!!!!!!!!!!!!!!!!!   callstack dtor out\n");
 }
 
 bool callstack_tracker::push_frame(const char *class_name, const char *func,
@@ -185,55 +160,77 @@ bool callstack_tracker::update_line(int line)
   return true;
 }
 
+// helpful macro makes sure we stay within our buffer for string storage of the stack trace.
+#define CHECK_SPACE_IN_BUFFER(desired_chunk) \
+  /* being slightly paranoid about the space, but we don't want any buffer overflows. */ \
+  if (space_used_in_buffer + desired_chunk >= full_size_needed - 4) { \
+    printf("callstack_tracker::full_trace: failure in size estimation--we would have blown out of the buffer"); \
+    return to_return; \
+  } else { \
+    space_used_in_buffer += desired_chunk; \
+  }
+  
 char *callstack_tracker::full_trace() const
 {
   auto_synchronizer l(callstack_tracker::__callstack_tracker_synchronizer());
 
   if (_unusable) return strdup("");
-//printf("fulltrace in\n");
-  char *to_return = (char *)malloc(full_trace_size());
+  int full_size_needed = full_trace_size();
+  char *to_return = (char *)malloc(full_size_needed);
+//printf("fulltrace allocated %d bytes for trace.\n", full_size_needed);
   to_return[0] = '\0';
   if (!_depth) {
     strcat(to_return, emptiness_note);
     return to_return;
   }
+
   const int initial_len = MAX_TEXT_FIELD + 8;
   char temp[initial_len];
-  int allowed_len = initial_len;
-    // space provided for one text line.
+  int space_left_in_line;  // the space provided for one text line.
+
+  int space_used_in_buffer = 0;
+    /* tracks whether we're getting close to the buffer limit.  technically, this
+    should not happen, since we calculated the space ahead of time... but it is good
+    to ensure we don't overflow the buffer in case we were not accurate. */
+
   // start at top most active frame and go down towards bottom most.
   for (int i = _depth; i >= 1; i--) {
+    CHECK_SPACE_IN_BUFFER(1);
     strcat(to_return, "\t");  // we left space for this and \n at end.
+    space_left_in_line = initial_len;  // reset our counter per line now.
     temp[0] = '\0';
     int len_class = strlen(_bt->_records[i]._class);
     int len_func = strlen(_bt->_records[i]._func);
-    if (allowed_len > len_class + len_func + 6) {
-      allowed_len -= len_class + len_func + 6;
+    if (space_left_in_line > len_class + len_func + 6) {
+      space_left_in_line -= len_class + len_func + 6;
       sprintf(temp, "\"%s::%s\", ", _bt->_records[i]._class,
           _bt->_records[i]._func);
+      CHECK_SPACE_IN_BUFFER(strlen(temp));
       strcat(to_return, temp);
     }
 
     temp[0] = '\0';
     int len_file = strlen(_bt->_records[i]._file);
-    if (allowed_len > len_file + 4) {
-      allowed_len -= len_file + 4;
+    if (space_left_in_line > len_file + 4) {
+      space_left_in_line -= len_file + 4;
       sprintf(temp, "\"%s\", ", _bt->_records[i]._file);
+      CHECK_SPACE_IN_BUFFER(strlen(temp));
       strcat(to_return, temp);
     }
 
     temp[0] = '\0';
     sprintf(temp, "\"line=%d\"", _bt->_records[i]._line);
     int len_line = strlen(temp);
-    if (allowed_len > len_line) {
-      allowed_len -= len_line;
+    if (space_left_in_line > len_line) {
+      space_left_in_line -= len_line;
+      CHECK_SPACE_IN_BUFFER(strlen(temp));
       strcat(to_return, temp);
     }
 
+    CHECK_SPACE_IN_BUFFER(1);
     strcat(to_return, "\n");  // we left space for this already.
   }
 
-//printf("fulltrace out\n");
   return to_return;
 }
 
@@ -277,7 +274,7 @@ frame_tracking_instance::frame_tracking_instance(const char *class_name,
 {
   if (_frame_involved) {
 //printf("frametrackinst ctor in class=%s func=%s\n", class_name, func);
-    program_wide_stack_trace().push_frame(class_name, func, file, line);
+    thread_wide_stack_trace().push_frame(class_name, func, file, line);
 //printf("frametrackinst ctor out\n");
   }
 }
@@ -298,7 +295,7 @@ void frame_tracking_instance::clean()
 {
   if (_frame_involved) {
 //printf("frametrackinst clean\n");
-    program_wide_stack_trace().pop_frame();
+    thread_wide_stack_trace().pop_frame();
   }
   _frame_involved = false;
   free(_class); _class = NULL_POINTER;
@@ -331,7 +328,7 @@ void frame_tracking_instance::assign(const char *class_name, const char *func,
 void update_current_stack_frame_line_number(int line)
 {
 //printf("frametrackinst updatelinenum in\n");
-  program_wide_stack_trace().update_line(line);
+  thread_wide_stack_trace().update_line(line);
 //printf("frametrackinst updatelinenum out\n");
 }
 
