@@ -17,12 +17,9 @@ var globals_vars =
     [ "n", "globals_vars_n.html", null ],
     [ "o", "globals_vars_o.html", null ],
     [ "p", "globals_vars_p.html", null ],
-    [ "q", "globals_vars_q.html", null ],
     [ "r", "globals_vars_r.html", null ],
     [ "s", "globals_vars_s.html", null ],
     [ "t", "globals_vars_t.html", null ],
-    [ "u", "globals_vars_u.html", null ],
     [ "v", "globals_vars_v.html", null ],
-    [ "w", "globals_vars_w.html", null ],
-    [ "y", "globals_vars_y.html", null ]
+    [ "w", "globals_vars_w.html", null ]
 ];
\ No newline at end of file
